##### Analysis of the inter-individual difference between suckling blocks ################
library(caret)
library(dplyr)

#Load blocks (2s blocks/windows)
nurii <- read.csv("~/Supplemental_Data_S2.csv")
str(nurii) #inspect data

#Prepare
nurii$nc_file <- factor(nurii$nc_file, levels = c("Jaune_14sept2018_calf_new","Jaune_06aout2019_calf_new",
                                                  "Orange_09aout2019_calf_new"),
                        labels = c("Calf1","Calf2",
                                   "Calf3")) #Rename deployment id
oo= filter(nurii,  clust == "nursing") #Use only nursing (suckling) blocks
oo$ODBA = oo$dbamean*9.80665 #G to m/s2

# Data visualisation --------------------------------------------------------------------
library(ggplot2)
library(gridExtra)

a = ggplot(oo,aes(x=nc_file, y=Pmean, fill = nc_file))+
  geom_violin(fill = "grey90")+geom_boxplot(width = 0.1)+geom_jitter()+
  theme_elsevier(base_size = 11, base_family = "")+ scale_y_reverse()+
  theme(legend.position = "none",
        axis.ticks.x=element_blank(),axis.title.x=element_blank())
b = ggplot(oo,aes(x=nc_file, y=DRmean, fill = nc_file))+
  geom_violin(fill = "grey90")+geom_boxplot(width = 0.1)+geom_jitter()+
  theme_elsevier(base_size = 11, base_family = "")+ 
  theme(legend.position = "none",
        axis.ticks.x=element_blank(),axis.title.x=element_blank())
c = ggplot(oo,aes(x=nc_file, y=smean, fill = nc_file))+
  geom_violin(fill = "grey90")+geom_boxplot(width = 0.1)+geom_jitter()+
  theme_elsevier(base_size = 11, base_family = "")+ 
  theme(legend.position = "none",
        axis.ticks.x=element_blank(),axis.title.x=element_blank())
d = ggplot(oo,aes(x=nc_file, y=FSRmean, fill = nc_file))+
  geom_violin(fill = "grey90")+geom_boxplot(width = 0.1)+geom_jitter()+
  theme_elsevier(base_size = 11, base_family = "")+ 
  theme(legend.position = "none",
        axis.ticks.x=element_blank(),axis.title.x=element_blank())
e = ggplot(oo,aes(x=nc_file, y=pitchmean, fill = nc_file))+
  geom_violin(fill = "grey90")+geom_boxplot(width = 0.1)+geom_jitter()+
  theme_elsevier(base_size = 11, base_family = "")+ 
  theme(legend.position = "none",
        axis.ticks.x=element_blank(),axis.title.x=element_blank())
f = ggplot(oo,aes(x=nc_file, y=rollmean, fill = nc_file))+
  geom_violin(fill = "grey90")+geom_boxplot(width = 0.1)+geom_jitter()+
  theme_elsevier(base_size = 11, base_family = "")+ 
  theme(legend.position = "none",
        axis.ticks.x=element_blank(),axis.title.x=element_blank())
g = ggplot(oo,aes(x=nc_file, y=rollratemean, fill = nc_file))+
  geom_violin(fill = "grey90")+geom_boxplot(width = 0.1)+geom_jitter()+
  theme_elsevier(base_size = 11, base_family = "")+ 
  theme(legend.position = "none",
        axis.ticks.x=element_blank(),axis.title.x=element_blank())
h = ggplot(oo,aes(x=nc_file, y=ODBA, fill = nc_file))+
  geom_violin(fill = "grey90")+geom_boxplot(width = 0.1)+geom_jitter()+
  theme_elsevier(base_size = 11, base_family = "")+ 
  theme(legend.position = "none",
        axis.ticks.x=element_blank(),axis.title.x=element_blank())
grid.arrange(a, b,c,d,e,f,g,h,ncol=2)

# Random Forest --------------------------------------------------------------------
library(randomForest)

nursing_blocks_ALL=oo;
table(nursing_blocks_ALL$nc_file) #To view N
nursing_blocks_ALL_RF <- randomForest(nc_file~Pmean+Pskew+Pkur+Pmin+Pmax+Pvar+
                            DRmean+DRskew+DRkur+DRmin+DRmax+DRvar+
                            smean+sskew+skur+smin+smax+svar+
                            FSRmean+
                            pitchmean+pitchskew+pitchkur+pitchmin+pitchmax+pitchvar+
                            rollmean+rollskew+rollkur+rollmin+rollmax+rollvar+
                            rollratemean+rollrateskew+rollratekur+rollratemin+rollratemax+rollratevar+
                            dbamean+dbaskew+dbakur+dbamin+dbamax+dbavar, sampsize =
                            c(49,49,49), data = oo, ntree = 500, mtry = 3, na.action = na.roughfix) #Train random forest using all features

print(nursing_blocks_ALL_RF)
plot(nursing_blocks_ALL_RF$err.rate[, 1], type = "l", xlab = "ntree", ylab
     = "erreur OOB")
aa  =nursing_blocks_ALL_RF$importance[order(nursing_blocks_ALL_RF$importance[, 1], decreasing = TRUE), ]
aa #Features importance (Gini)
plot(aa)

#Restrict features
nursing_blocks_ALL_RF2 <- randomForest(nc_file~ #Pmax+Pmean+pitchmax+pitchmin+pitchmean+Pmin+ smean+smin+smax+
                             FSRmean+rollmean+rollmin+DRmin+rollmax+
                             DRvar+dbamax+ dbamean+DRmean+ dbavar+pitchvar+
                             DRmax+ svar+dbamin+rollratemax+rollvar+
                             Pvar+rollratemean+Pskew+dbaskew+ rollratemin+ dbakur+
                             rollkur+rollratekur+skur+rollskew+DRskew+
                             sskew+pitchskew+rollrateskew+pitchkur+DRkur+ 
                             rollratevar+Pkur,
                           sampsize = c(49,49,49), data = oo, ntree = 500, mtry = 3, na.action = na.roughfix) #Train again but excluding the most important features 
aa  =nursing_blocks_ALL_RF2$importance[order(nursing_blocks_ALL_RF2$importance[, 1], decreasing = TRUE), ]
aa #Features importance (Gini)
plot(aa)

#Did the error rate change?
print(nursing_blocks_ALL_RF) #All features
print(nursing_blocks_ALL_RF2) #Restricted features
