##### SUCKLING CHARACTERISTICS #####################
library(caret)
library(dplyr)

#Load CSV
nurs <-read.csv("~/Supplemental_Data_S1.csv")

#Prepare data
nurs$ODBA = nurs$dbamean*9.80665 #G -> m/s2
nurs$Behavior2=nurs$clust #Store a copy of 'clust' in 'Behavior2'
nurs$Behavior2 <- factor(nurs$Behavior2, levels = c("Non suckling", "Suckling"),
                         labels = c("Non-suckling", "Suckling")) #Rename
nurs$phase <- factor(nurs$phase, levels = c("descent","bottom","notdiving"),
                     labels = c("Descent","Bottom", "Surface")) #Rename
nurs$nc_file <- factor(nurs$nc_file, levels = c("Jaune_14sept2018_calf_new", "Jaune_06aout2019_calf_new","Orange_09aout2019_calf_new"),
                        labels = c("Calf1", "Calf2","Calf3")) #Use directly the attributed calf's name
table(nurs$Behavior) #Show N
nurs2= filter(nurs,  Behavior2 == 'Suckling') #Suckling only

NN = aggregate(Pmean ~ phase + nc_file , data = nurs2, length) #N per calf per activity phase
NN #Show 

#Summary statistics

#Average depth
a = aggregate(Pmean ~ phase + nc_file, data = nurs2, mean)
b = aggregate(Pmean ~ phase + nc_file, data = nurs2, sd)
c = aggregate(Pmean ~ phase + nc_file, data = nurs2, min)
d = aggregate(Pmean ~ phase + nc_file, data = nurs2, max)
round(data.frame(a[,3],b[,3],c[,3],d[,3]),1)
data.frame(NN[,2],NN[,1],round(data.frame(a[,3],b[,3],c[,3],d[,3]),1)) #Show calf id, activity phase, mean, sd, min, max 

#Average depth rate
a = aggregate(DRmean ~ phase + nc_file, data = nurs2, mean)
b = aggregate(DRmean ~ phase + nc_file, data = nurs2, sd)
c = aggregate(DRmean ~ phase + nc_file, data = nurs2, min)
d = aggregate(DRmean ~ phase + nc_file, data = nurs2, max)
data.frame(NN[,2],NN[,1],round(data.frame(a[,3],b[,3],c[,3],d[,3]),1)) #Show calf id, activity phase, mean, sd, min, max 

#Average speed
a = aggregate(smean ~ phase + nc_file, data = nurs2, mean)
b = aggregate(smean ~ phase + nc_file, data = nurs2, sd)
c = aggregate(smean ~ phase + nc_file, data = nurs2, min)
d = aggregate(smean ~ phase + nc_file, data = nurs2, max)
data.frame(NN[,2],NN[,1],round(data.frame(a[,3],b[,3],c[,3],d[,3]),1)) #Show calf id, activity phase, mean, sd, min, max 

#Average FSR
a = aggregate(FSRmean ~ phase + nc_file, data = nurs2, mean)
b = aggregate(FSRmean ~ phase + nc_file, data = nurs2, sd)
c = aggregate(FSRmean ~ phase + nc_file, data = nurs2, min)
d = aggregate(FSRmean ~ phase + nc_file, data = nurs2, max)
data.frame(NN[,2],NN[,1],round(data.frame(a[,3],b[,3],c[,3],d[,3]),1)) #Show calf id, activity phase, mean, sd, min, max 

#Average pitch
a= aggregate(pitchmean ~ phase + nc_file, data = nurs2, mean)
b= aggregate(pitchmean ~ phase + nc_file, data = nurs2, sd)
c= aggregate(pitchmean ~ phase + nc_file, data = nurs2, min)
d= aggregate(pitchmean ~ phase + nc_file, data = nurs2, max)
data.frame(NN[,2],NN[,1],round(data.frame(a[,3],b[,3],c[,3],d[,3]),0)) #Show calf id, activity phase, mean, sd, min, max 

#Average roll (absolute)
a= aggregate(rollmean ~ phase + nc_file, data = nurs2, mean)
b= aggregate(rollmean ~ phase + nc_file, data = nurs2, sd)
c= aggregate(rollmean ~ phase + nc_file, data = nurs2, min)
d= aggregate(rollmean ~ phase + nc_file, data = nurs2, max)
data.frame(NN[,2],NN[,1],round(data.frame(a[,3],b[,3],c[,3],d[,3]),0)) #Show calf id, activity phase, mean, sd, min, max 

#Average roll rate
a= aggregate(rollratemean ~ phase + nc_file, data = nurs2, mean)
b= aggregate(rollratemean ~ phase + nc_file, data = nurs2, sd)
c= aggregate(rollratemean ~ phase + nc_file, data = nurs2, min)
d= aggregate(rollratemean ~ phase + nc_file, data = nurs2, max)
data.frame(NN[,2],NN[,1],round(data.frame(a[,3],b[,3],c[,3],d[,3]),1)) #Show calf id, activity phase, mean, sd, min, max 

#Average ODBA
a= aggregate(ODBA ~ phase + nc_file, data = nurs2, mean)
b= aggregate(ODBA ~ phase + nc_file, data = nurs2, sd)
c= aggregate(ODBA ~ phase + nc_file, data = nurs2, min)
d= aggregate(ODBA ~ phase + nc_file, data = nurs2, max)
data.frame(NN[,2],NN[,1],round(data.frame(a[,3],b[,3],c[,3],d[,3]),1)) #Show calf id, activity phase, mean, sd, min, max 


##### SCRIPT FOR MIXED EFFECT MODEL ################
#Data preparation
str(nurs) #Data structure
unique(nurs$Behavior2) #Preview classes
nuri = nurs

nuri$phase <- factor(nuri$phase, levels = c("Bottom","Descent", "Surface"),
                     labels = c("Bottom","Descent", "Surface")) #Rename

#Model fit + post-hoc ------------------------------------------------
library(emmeans)
library(lme4)

#Proceed variable one by one: DRmean, smean, etc. 
model = lmer(DRmean ~ Behavior2*phase+(1|nc_file), data=nuri) 

plot_model(model, type='diag')[[1]]
plot_model(model, type='diag')[[2]]
plot_model(model, type='diag')[[3]]
plot_model(model, type='diag')[[4]]

summary(model)
confint(model,level = 0.95)

#Post-hoc
em <- emmeans(model, ~ Behavior2*phase)
em
pairs(em)
emmip(em, Behavior2~phase)
